# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["DatasetFinalizeFileUploadResponse", "DatasetFile", "DatasetFileColumn"]


class DatasetFileColumn(BaseModel):
    id: str
    """The ID of the dataset file."""

    created_at: datetime = FieldInfo(alias="createdAt")

    index: int
    """Index of the column within the dataset file."""

    literal_name: str = FieldInfo(alias="literalName")
    """The literal name for the column."""

    updated_at: datetime = FieldInfo(alias="updatedAt")

    dtype: Optional[
        Literal[
            "DATASET_COLUMN_D_TYPE_UNSPECIFIED",
            "DATASET_COLUMN_D_TYPE_INT32",
            "DATASET_COLUMN_D_TYPE_INT64",
            "DATASET_COLUMN_D_TYPE_FLOAT32",
            "DATASET_COLUMN_D_TYPE_FLOAT64",
            "DATASET_COLUMN_D_TYPE_STRING",
            "DATASET_COLUMN_D_TYPE_BYTES",
            "DATASET_COLUMN_D_TYPE_ANY",
        ]
    ] = None
    """Datatypes for a column in a dataset file.

    We likely don't need everything here, but it's good to be explicit, for example
    to avoid unknowingly coercing int64 values into int32. Encoding for text is
    UTF_8 unless indicated otherwise.
    """


class DatasetFile(BaseModel):
    id: str
    """The ID of the dataset file."""

    columns: List[DatasetFileColumn]

    content_md5_hash: str = FieldInfo(alias="contentMd5Hash")

    created_at: datetime = FieldInfo(alias="createdAt")

    dataset_id: str = FieldInfo(alias="datasetId")
    """The ID of the corresponding dataset."""

    file_size_bytes: int = FieldInfo(alias="fileSizeBytes")

    num_cols: int = FieldInfo(alias="numCols")

    num_rows: int = FieldInfo(alias="numRows")

    updated_at: datetime = FieldInfo(alias="updatedAt")


class DatasetFinalizeFileUploadResponse(BaseModel):
    dataset_file: Optional[DatasetFile] = FieldInfo(alias="datasetFile", default=None)
    """Information about the dataset file if the upload was successful"""



#!/usr/bin/env -S rye run python

import os

import pandas as pd

from lastmile.lib.auto_eval import AutoEval, BuiltinMetrics

client = AutoEval(
    # This is the default and can be omitted
    api_token=os.environ.get("LASTMILE_API_TOKEN"),
)

input_df = pd.DataFrame(
    {
        "input": [
            "Can you tell me the weight limit for carry-on bags?",
            "What gate is my flight SA795 departing from?",
            "Can I bring my pet on the plane?",
        ],
        "output": [
            "The weight limit for carry-on bags is 7kg.",
            "Your flight SA795 is departing from JFK at 6:30PM.",
            "Yes, you can bring your pet, but it must fit under the seat in front of you and there is a pet fee.",
        ],
        "ground_truth": [
            "7kg",
            "SA795: JFK Terminal 4, Gate 42, 6:30PM departure",
            "Pets are not allowed on StrikeAir flights.",
        ],
    }
)


output_df = client.evaluate_data(input_df, BuiltinMetrics.FAITHFULNESS)
print(output_df)
#                                                input                                             output                                      ground_truth  Faithfulness_score
# 0  Can you tell me the weight limit for carry-on ...         The weight limit for carry-on bags is 7kg.                                               7kg            0.998831
# 1       What gate is my flight SA795 departing from?  Your flight SA795 is departing from JFK at 6:3...  SA795: JFK Terminal 4, Gate 42, 6:30PM departure            0.998952
# 2                   Can I bring my pet on the plane?  Yes, you can bring your pet, but it must fit u...        Pets are not allowed on StrikeAir flights.            0.000892



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Union, Iterable
from datetime import datetime
from typing_extensions import Literal, Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = [
    "DatasetGetViewParams",
    "Filter",
    "FilterNumericCriteria",
    "FilterStringCriteria",
    "FilterTagsCriteria",
    "FilterTimeRangeCriteria",
]


class DatasetGetViewParams(TypedDict, total=False):
    dataset_file_id: Required[Annotated[str, PropertyInfo(alias="datasetFileId")]]
    """
    The ID of the (pinned) dataset file from which to retrieve content. Requests
    iterating over pages of results are recommended to use this pinned identifier
    after the first page in order to prevent any effects from a dataset changing
    between the queries.
    """

    dataset_id: Required[Annotated[str, PropertyInfo(alias="datasetId")]]
    """The ID of the dataset from which to retrieve content.

    When specified, gets data from the current file in the dataset.
    """

    filters: Required[Iterable[Filter]]

    after: int
    """Pagination: The index, by row-order, after which to query results."""

    limit: int
    """Pagination: The maximum number of results to return on this page."""

    order_by: Annotated[str, PropertyInfo(alias="orderBy")]
    """Column to order results by"""

    order_direction: Annotated[str, PropertyInfo(alias="orderDirection")]
    """Direction to order results ("asc" or "desc")"""

    use_datasets_service: Annotated[bool, PropertyInfo(alias="useDatasetsService")]


class FilterNumericCriteria(TypedDict, total=False):
    float_value: Required[Annotated[float, PropertyInfo(alias="floatValue")]]

    int_value: Required[Annotated[int, PropertyInfo(alias="intValue")]]

    operator: Required[
        Literal[
            "OPERATOR_UNSPECIFIED",
            "OPERATOR_EQUALS",
            "OPERATOR_NOT_EQUALS",
            "OPERATOR_GREATER_THAN",
            "OPERATOR_GREATER_THAN_OR_EQUAL",
            "OPERATOR_LESS_THAN",
            "OPERATOR_LESS_THAN_OR_EQUAL",
        ]
    ]


class FilterStringCriteria(TypedDict, total=False):
    operator: Required[
        Literal[
            "OPERATOR_UNSPECIFIED",
            "OPERATOR_EQUALS",
            "OPERATOR_NOT_EQUALS",
            "OPERATOR_CONTAINS",
            "OPERATOR_STARTS_WITH",
            "OPERATOR_ENDS_WITH",
        ]
    ]

    value: Required[str]


class FilterTagsCriteria(TypedDict, total=False):
    operator: Required[Literal["OPERATOR_UNSPECIFIED", "OPERATOR_HAS_ANY", "OPERATOR_HAS_ALL", "OPERATOR_HAS_NONE"]]

    tags: Required[List[str]]


class FilterTimeRangeCriteria(TypedDict, total=False):
    operator: Required[Literal["OPERATOR_UNSPECIFIED", "OPERATOR_BEFORE", "OPERATOR_AFTER", "OPERATOR_BETWEEN"]]

    timestamp: Required[Annotated[Union[str, datetime], PropertyInfo(format="iso8601")]]

    end_timestamp: Annotated[Union[str, datetime], PropertyInfo(alias="endTimestamp", format="iso8601")]


class Filter(TypedDict, total=False):
    column_name: Required[Annotated[str, PropertyInfo(alias="columnName")]]

    numeric_criteria: Required[Annotated[FilterNumericCriteria, PropertyInfo(alias="numericCriteria")]]

    string_criteria: Required[Annotated[FilterStringCriteria, PropertyInfo(alias="stringCriteria")]]

    tags_criteria: Required[Annotated[FilterTagsCriteria, PropertyInfo(alias="tagsCriteria")]]

    time_range_criteria: Required[Annotated[FilterTimeRangeCriteria, PropertyInfo(alias="timeRangeCriteria")]]
